.. highlight:: shell

============
Installation
============

At the command line either via easy_install or pip::

    $ pip install pureyaml

::

    $ easy_install pureyaml

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pureyaml
    $ pip install pureyaml

**Uninstall**::

    $ pip uninstall pureyaml
